aboutsummaryrefslogtreecommitdiff
path: root/engines/sci/sfx/player.h
diff options
context:
space:
mode:
authorMax Horn2009-03-06 07:25:06 +0000
committerMax Horn2009-03-06 07:25:06 +0000
commit5e2ee01b39392eecd966624e1d0efc75ee41bc10 (patch)
tree11bc9449bf493223a13d78739bb6702bb56728fc /engines/sci/sfx/player.h
parent0c681f85a4035d44948e53584cc4d5c8ca324ba9 (diff)
downloadscummvm-rg350-5e2ee01b39392eecd966624e1d0efc75ee41bc10.tar.gz
scummvm-rg350-5e2ee01b39392eecd966624e1d0efc75ee41bc10.tar.bz2
scummvm-rg350-5e2ee01b39392eecd966624e1d0efc75ee41bc10.zip
SCI: Renamed lots of classes related to song iterators; allocate song iterators via new/delete instead of malloc/free
svn-id: r39148
Diffstat (limited to 'engines/sci/sfx/player.h')
-rw-r--r--engines/sci/sfx/player.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/engines/sci/sfx/player.h b/engines/sci/sfx/player.h
index 1d4ed9cd4f..bbb893c91e 100644
--- a/engines/sci/sfx/player.h
+++ b/engines/sci/sfx/player.h
@@ -57,7 +57,7 @@ struct sfx_player_t {
** Returns : (int) SFX_OK on success, SFX_ERROR on failure
*/
- int (*add_iterator)(song_iterator_t *it, uint32 start_time);
+ int (*add_iterator)(SongIterator *it, uint32 start_time);
/* Adds an iterator to the song player
** Parameters: (songx_iterator_t *) it: The iterator to play
** (uint32) start_time: The time to assume as the
@@ -79,9 +79,9 @@ struct sfx_player_t {
** Returns : (int) SFX_OK on success, SFX_ERROR on failure
*/
- int (*iterator_message)(song_iterator_message_t msg);
+ int (*iterator_message)(SongIteratorMessage msg);
/* Transmits a song iterator message to the active song
** Parameters: (song_iterator_message_t) msg: The message to transmit
** Returns : (int) SFX_OK on success, SFX_ERROR on failure
** OPTIONAL -- may be NULL
** If this method is not present, sending messages will stop
@@ -141,7 +141,7 @@ void sfx_reset_player();
** Returns: Nothing.
*/
-song_iterator_t *sfx_iterator_combine(song_iterator_t *it1, song_iterator_t *it2);
+SongIterator *sfx_iterator_combine(SongIterator *it1, SongIterator *it2);
/* Combines two song iterators into one
** Parameters: (sfx_iterator_t *) it1: One of the two iterators, or NULL
** (sfx_iterator_t *) it2: The other iterator, or NULL
@@ -79,9 +79,9 @@ struct sfx_player_t {
/* Transmits a song iterator message to the active song
- ** Parameters: (song_iterator_message_t) msg: The message to transmit
+ ** Parameters: (SongIteratorMessage) msg: The message to transmit
** Returns : (int) SFX_OK on success, SFX_ERROR on failure
** OPTIONAL -- may be NULL